==> pip_autocompile-0.7.11.tar.gz: pip_autocompile-0.7.11/README.md <==
# pip-autocompile

[![build](https://github.com/KSmanis/pip-autocompile/actions/workflows/build.yml/badge.svg)](https://github.com/KSmanis/pip-autocompile/actions/workflows/build.yml)
[![PyPI version](https://img.shields.io/pypi/v/pip-autocompile.svg)](https://pypi.org/project/pip-autocompile/)
[![pre-commit enabled](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Renovate enabled](https://img.shields.io/badge/renovate-enabled-brightgreen.svg?logo=renovatebot&logoColor=white)](https://renovatebot.com/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![mypy: strict](https://img.shields.io/badge/mypy-strict-2a6db2)](http://mypy-lang.org/)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=KSmanis_pip-autocompile&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=KSmanis_pip-autocompile)
[![codecov](https://codecov.io/gh/KSmanis/pip-autocompile/branch/master/graph/badge.svg?token=47HDGLM2NQ)](https://codecov.io/gh/KSmanis/pip-autocompile)
[![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg)](https://conventionalcommits.org)

Automate pip-compile for multiple environments.

## Dependencies

### Runtime

- [pip-tools](https://github.com/jazzband/pip-tools): Compile requirements
  locally

==> pip_autocompile-0.7.13.tar.gz: pip_autocompile-0.7.13/README.md <==
# pip-autocompile

[![build](https://github.com/KSmanis/pip-autocompile/actions/workflows/build.yml/badge.svg)](https://github.com/KSmanis/pip-autocompile/actions/workflows/build.yml)
[![PyPI version](https://img.shields.io/pypi/v/pip-autocompile.svg)](https://pypi.org/project/pip-autocompile/)
[![pre-commit enabled](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Renovate enabled](https://img.shields.io/badge/renovate-enabled-brightgreen.svg?logo=renovatebot&logoColor=white)](https://renovatebot.com/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![mypy: strict](https://img.shields.io/badge/mypy-strict-2a6db2)](http://mypy-lang.org/)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=KSmanis_pip-autocompile&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=KSmanis_pip-autocompile)
[![codecov](https://codecov.io/gh/KSmanis/pip-autocompile/branch/master/graph/badge.svg?token=47HDGLM2NQ)](https://codecov.io/gh/KSmanis/pip-autocompile)
[![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-%23FE5196?logo=conventionalcommits&logoColor=white)](https://conventionalcommits.org)

Automate pip-compile for multiple environments.

## Dependencies

### Runtime

- [pip-tools](https://github.com/jazzband/pip-tools): Compile requirements
  locally
